@@ -21,13 +21,13 @@ def mock_sync_client(sync_client):
 
 
 @pytest.fixture
-def mocker():
+def rest_sync_mocker():
     with requests_mock.Mocker() as m:
         yield m
 
 
 @pytest.fixture
-def mock_json_resp():
+def rest_sync_mock_resp():
     return {}
 
 
